==> vlc2-2.2.8-i486-2alien.txz: install/doinst.sh <==
# Update the desktop database:
if [ -x usr/bin/update-desktop-database ]; then
  chroot . /usr/bin/update-desktop-database usr/share/applications > /dev/null
2>&1
fi

# Update hicolor theme cache:
if [ -d usr/share/icons/hicolor ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    chroot . /usr/bin/gtk-update-icon-cache -f -t usr/share/icons/hicolor 1> /dev/null 2> /dev/null
  fi
fi

# Update the mime database:
if [ -x usr/bin/update-mime-database ]; then
  chroot . /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

# Remove old cache data and regenerate the file:
chroot . <<EOCR 2>/dev/null
cd /usr/lib/vlc
find . -name "plugins*.dat" -exec rm -f {} \;
echo "Generating VLC plugins cache data..."
DISPLAY="" ./vlc-cache-gen -f .
EOCR

( cd usr/lib/vlc ; rm -rf libvlc_vdpau.so.0 )
( cd usr/lib/vlc ; ln -sf libvlc_vdpau.so.0.0.0 libvlc_vdpau.so.0 )
( cd usr/lib/vlc ; rm -rf libvlc_vdpau.so )
( cd usr/lib/vlc ; ln -sf libvlc_vdpau.so.0.0.0 libvlc_vdpau.so )
( cd usr/lib ; rm -rf libvlccore.so.8 )
( cd usr/lib ; ln -sf libvlccore.so.8.0.1 libvlccore.so.8 )
( cd usr/lib ; rm -rf libvlccore.so )
( cd usr/lib ; ln -sf libvlccore.so.8.0.1 libvlccore.so )
( cd usr/lib ; rm -rf libvlc.so )
( cd usr/lib ; ln -sf libvlc.so.5.5.1 libvlc.so )
( cd usr/lib ; rm -rf libvlc.so.5 )
( cd usr/lib ; ln -sf libvlc.so.5.5.1 libvlc.so.5 )
( cd usr/share/vlc/projectM/fonts ; rm -rf Vera.ttf )
( cd usr/share/vlc/projectM/fonts ; ln -sf /usr/share/fonts/TTF/DejaVuSans.ttf Vera.ttf )
( cd usr/share/vlc/projectM/fonts ; rm -rf VeraMono.ttf )
( cd usr/share/vlc/projectM/fonts ; ln -sf /usr/share/fonts/TTF/DejaVuSansMono.ttf VeraMono.ttf )

==> vlc-3.0.21-i586-1alien.txz: install/doinst.sh <==
# Update the desktop database:
if [ -x usr/bin/update-desktop-database ]; then
  chroot . /usr/bin/update-desktop-database usr/share/applications > /dev/null
2>&1
fi

# Update hicolor theme cache:
if [ -d usr/share/icons/hicolor ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    chroot . /usr/bin/gtk-update-icon-cache -f -t usr/share/icons/hicolor 1> /dev/null 2> /dev/null
  fi
fi

# Update the mime database:
if [ -x usr/bin/update-mime-database ]; then
  chroot . /usr/bin/update-mime-database usr/share/mime >/dev/null 2>&1
fi

# Remove old cache data and regenerate the file:
chroot . <<EOCR 2>/dev/null
cd /usr/lib/vlc
find . -name "plugins*.dat" -exec rm -f {} \;
echo "Generating VLC plugins cache data..."
DISPLAY="" ./vlc-cache-gen /usr/lib/vlc/plugins
EOCR

( cd usr/lib ; rm -rf libvlc.so )
( cd usr/lib ; ln -sf libvlc.so.5.6.1 libvlc.so )
( cd usr/lib ; rm -rf libvlc.so.5 )
( cd usr/lib ; ln -sf libvlc.so.5.6.1 libvlc.so.5 )
( cd usr/lib ; rm -rf libvlccore.so )
( cd usr/lib ; ln -sf libvlccore.so.9.0.1 libvlccore.so )
( cd usr/lib ; rm -rf libvlccore.so.9 )
( cd usr/lib ; ln -sf libvlccore.so.9.0.1 libvlccore.so.9 )
( cd usr/lib/vlc ; rm -rf libvlc_pulse.so )
( cd usr/lib/vlc ; ln -sf libvlc_pulse.so.0.0.0 libvlc_pulse.so )
( cd usr/lib/vlc ; rm -rf libvlc_pulse.so.0 )
( cd usr/lib/vlc ; ln -sf libvlc_pulse.so.0.0.0 libvlc_pulse.so.0 )
( cd usr/lib/vlc ; rm -rf libvlc_vdpau.so )
( cd usr/lib/vlc ; ln -sf libvlc_vdpau.so.0.0.0 libvlc_vdpau.so )
( cd usr/lib/vlc ; rm -rf libvlc_vdpau.so.0 )
( cd usr/lib/vlc ; ln -sf libvlc_vdpau.so.0.0.0 libvlc_vdpau.so.0 )
( cd usr/lib/vlc ; rm -rf libvlc_xcb_events.so )
( cd usr/lib/vlc ; ln -sf libvlc_xcb_events.so.0.0.0 libvlc_xcb_events.so )
( cd usr/lib/vlc ; rm -rf libvlc_xcb_events.so.0 )
( cd usr/lib/vlc ; ln -sf libvlc_xcb_events.so.0.0.0 libvlc_xcb_events.so.0 )
( cd usr/share/vlc/projectM/fonts ; rm -rf Vera.ttf )
( cd usr/share/vlc/projectM/fonts ; ln -sf /usr/share/fonts/TTF/DejaVuSans.ttf Vera.ttf )
( cd usr/share/vlc/projectM/fonts ; rm -rf VeraMono.ttf )
( cd usr/share/vlc/projectM/fonts ; ln -sf /usr/share/fonts/TTF/DejaVuSansMono.ttf VeraMono.ttf )
